@@ -8,6 +8,7 @@ import devpi
 from devpi.util.lazydecorator import lazydecorator
 from devpi.util import url as urlutil
 from devpi import log, cached_property
+from devpi import __version__ as client_version
 from devpi.use import Current
 import requests
 import json
@@ -93,7 +94,8 @@ class Hub:
         session.ConnectionError = requests.exceptions.ConnectionError
         return session
 
-    def http_api(self, method, url, kvdict=None, quiet=False, auth=notset):
+    def http_api(self, method, url, kvdict=None, quiet=False, auth=notset,
+        check_version=True):
         """ send a json request and return a HTTPReply object which
         adds some extra methods to the requests's Reply object.
 
@@ -116,6 +118,9 @@ class Hub:
             self.fatal("could not connect to %r" % (url,))
         self._last_http_status = r.status_code
 
+        if r.url != url:
+            self.info("*redirected: %s" %(r.url,))
+
         reply = HTTPReply(r)
 
         # if we get a 401 it means our auth info is expired or not present
@@ -123,6 +128,9 @@ class Hub:
             if self.current.del_auth():
                 self.error("removed expired authentication information")
 
+        if check_version:
+            verify_reply_version(self, reply)
+
         if r.status_code in (200, 201):
             # don't show any extra info on success code
             return reply
@@ -220,18 +228,26 @@ class Hub:
         if ret:
             self.fatal("****** process returned %s" % ret)
 
-    def report_popen(self, args, cwd=None):
+    def report_popen(self, args, cwd=None, extraenv=None):
         base = cwd or self.cwd
         rel = py.path.local(args[0]).relto(base)
         if not rel:
             rel = str(args[0])
-        self.line("--> $", rel, " ".join(args[1:]))
+        if extraenv is not None:
+            envadd = " [%s]" % ",".join(
+                ["%s=%s" % item for item in extraenv.items()])
+        else:
+            envadd = ""
+        self.line("--> $", rel, " ".join(args[1:]), envadd)
 
-    def popen_check(self, args):
+    def popen_check(self, args, extraenv=None):
         assert args[0], args
         args = [str(x) for x in args]
-        self.report_popen(args)
-        ret = subprocess.call(args)
+        self.report_popen(args, extraenv=extraenv)
+        env = os.environ.copy()
+        if extraenv is not None:
+            env.update(extraenv)
+        ret = subprocess.call(args, env=env)
         if ret != 0:
             self.fatal("command failed")
 
@@ -376,8 +392,8 @@ def add_generic_options(parser):
         help="show debug messages including more info on server requests")
     group.add_argument("-y", action="store_true", dest="yes",
         help="assume 'yes' on confirmation questions")
-    #group.add_argument("-v", "--verbose", action="store_true",
-    #    help="increase verbosity")
+    group.add_argument("-v", "--verbose", action="count",
+        help="increase verbosity")
     group.add_argument("--clientdir", action="store", metavar="DIR",
         default=os.path.expanduser(os.environ.get("DEVPI_CLIENTDIR",
                                                   "~/.devpi/client")),
@@ -551,11 +567,15 @@ def upload(parser):
     #parser.add_argument("-l", dest="showstatus",
     #    action="store_true", default=None,
     #    help="show remote versions, local version and package types")
-    parser.add_argument("--ver", dest="setversion",
-        action="store", default=None,
-        help="fill version string into setup.py, */__init__.py */conf.py files")
+    #parser.add_argument("--ver", dest="setversion",
+    #    action="store", default=None,
+    #    help="fill version string into setup.py, */__init__.py */conf.py files")
     #parser.add_argument("--incver", action="store_true",
     #    help="retrieve max remove version, increment and set it like --ver")
+    parser.add_argument("--no-vcs", action="store_true", dest="novcs",
+        help="don't VCS-export to a fresh dir, just execute setup.py scripts "
+             "directly using their dirname as current dir. ")
+
     parser.add_argument("--formats", default="sdist.tgz", action="store",
         help="comma separated list of build formats (passed to setup.py). "
              "Examples sdist.zip,bdist_egg,bdist_wheel,bdist_dumb.")
@@ -595,6 +615,10 @@ def test(parser):
         default=None, action="store", nargs=1,
         help="package specification to download and test")
 
+    parser.add_argument("--tox-args", metavar="toxargs", action="store",
+        dest="toxargs", default=None,
+        help="extra command line arguments for tox")
+
 @subcommand("devpi.push")
 def push(parser):
     """ push a release and releasefiles to an internal or external index.
@@ -639,6 +663,23 @@ def install(parser):
         help="uri or package file for installation from current index. """
     )
 
+def verify_reply_version(hub, reply):
+    acceptable_api_version = ("1",)
+    version = reply.headers.get("X-DEVPI-API-VERSION", None)
+    if version is None:
+        if not hasattr(hub, "_WARNAPI_DELIVERED"):
+            hub.error("WARN: devpi-client-%s got an unversioned reply, "
+                      "assuming API-VERSION 1 (as implemented by "
+                      "devpi-server-1.1)" % client_version)
+            hub._WARNAPI_DELIVERED = True
+        return
+    if version in acceptable_api_version:
+        return
+    hub.fatal("devpi-client-%s got a reply with API-VERSION %s, "
+              "acceptable are: %s" %(client_version, version,
+                                     ",".join(acceptable_api_version)))
+
+
 
 if __name__ == "__main__":
     main()
