@@ -1,6 +1,7 @@
 
 from __future__ import with_statement
 import os, sys
+import shlex
 import hashlib
 import mimetypes
 import posixpath
@@ -10,6 +11,7 @@ import argparse
 import pkg_resources
 import archive
 import json
+import tox
 
 from devpi.util import url as urlutil
 from devpi.util import version as verlib
@@ -51,7 +53,8 @@ class DevIndex:
         if hasattr(link, "md5"):
             md5 = hashlib.md5()
             md5.update(content)
-            assert md5.hexdigest() == link.md5
+            digest = md5.hexdigest()
+            assert digest == link.md5, (digest, link.md5)
             #self.hub.info("verified md5 ok", link.md5)
         path_archive = self.dir_download.join(link.basename)
         with path_archive.open("wb") as f:
@@ -64,37 +67,48 @@ class DevIndex:
         #req = pkg_resources.parse_requirements(pkgspec)[0]
         return self.remoteindex.getbestlink(pkgname)
 
-    def runtox(self, link, Popen, venv=None):
+    def runtox(self, link):
         path_archive = link.pkg.path_archive
 
-        env = os.environ.copy()
-
         # publishing some infos to the commands started by tox
         #setenv_devpi(self.hub, env, posturl=self.current.resultlog,
         #                  packageurl=link.href,
         #                  packagemd5=link.md5)
         jsonreport = link.pkg.rootdir.join("toxreport.json")
-        toxscript = py.path.local.sysfind("tox")
-        assert toxscript, "tox not found"
-        toxargs = [str(toxscript), "--installpkg", str(path_archive),
-                   "-i ALL=%s" % self.current.simpleindex,
+        toxargs = ["--installpkg", str(path_archive),
+                   "-i ALL=%s" % str(self.current.simpleindex),
                    "--result-json", str(jsonreport),
         ]
-        if venv is not None:
-            toxargs.append("-e" + venv)
+        toxargs.extend(self.get_tox_args())
 
-        self.hub.info("%s$ %s" %(link.pkg.path_unpacked, " ".join(toxargs)))
-        popen = Popen(toxargs, cwd=str(link.pkg.path_unpacked), env=env)
-        popen.communicate()
-        if popen.returncode != 2:  # KEYBOARDINTERRUPT prevents upload
-            jsondata = py.std.json.load(jsonreport.open("rb"))
+        self.hub.info("%s$ tox %s" %(link.pkg.path_unpacked,
+                      " ".join(toxargs)))
+        old = link.pkg.path_unpacked.chdir()
+        try:
+            try:
+                ret = tox.cmdline(toxargs)
+            except SystemExit as e:
+                ret = e.args[0]
+        finally:
+            old.chdir()
+        if ret != 2:
+            jsondata = json.load(jsonreport.open("rb"))
             post_tox_json_report(self.hub,
                                  self.hub.current.resultlog, jsondata)
-        if popen.returncode != 0:
-            self.hub.error("tox command failed", popen.returncode)
+        if ret != 0:
+            self.hub.error("tox command failed", ret)
             return 1
         return 0
 
+    def get_tox_args(self):
+        toxargs = []
+        args = self.hub.args
+        if args.venv is not None:
+            toxargs.append("-e" + args.venv)
+        if args.toxargs:
+            toxargs.extend(shlex.split(args.toxargs))
+        return toxargs
+
 def post_tox_json_report(hub, href, jsondata):
     hub.line("posting tox result data to %s" % href)
     r = hub.http_api("post", href, kvdict=jsondata)
@@ -121,15 +135,12 @@ class UnpackedPackage:
 
 
 def main(hub, args):
-    hub.require_valid_current_with_index()
+    current = hub.require_valid_current_with_index()
     tmpdir = py.path.local.make_numbered_dir("devpi-test", keep=3)
-    current = hub.current
-    if not current.exists():
-        hub.fatal("no api configuration found")
     devindex = DevIndex(hub, tmpdir, current)
     link = devindex.getbestlink(args.pkgspec[0])
     if not link:
         hub.fatal("could not find/receive link")
     devindex.download_and_unpack(link)
-    ret = devindex.runtox(link, Popen=hub.Popen, venv=args.venv)
+    ret = devindex.runtox(link)
     return ret
