@@ -63,6 +63,11 @@ class TestCheckout:
         assert result.rootpath.join("file").check()
         assert result.rootpath == newrepo.join(repo.basename)
 
+    def test_hg_export_disabled(self, uploadhub, repo, tmpdir, monkeypatch):
+        monkeypatch.setattr(uploadhub.args, "novcs", True)
+        checkout = Checkout(uploadhub, repo)
+        assert not checkout.hashg
+
     def test_hg_export_verify_setup(self, uploadhub, repo,
                                           tmpdir, monkeypatch):
         subdir = repo.mkdir("subdir")
@@ -168,7 +173,7 @@ class TestUploadFunctional:
         devpi("upload", "--dry-run")
         devpi("upload", "--dry-run", "--with-docs")
         devpi("upload", "--dry-run", "--only-docs")
-        devpi("upload", "--formats", "sdist.tbz")
+        devpi("upload", "--formats", "sdist.zip")
         devpi("upload", "--formats", "sdist.tgz,bdist_dumb")
 
         # logoff then upload
